
.. image:: https://github.com/guiferviz/happyml-py/raw/dev/doc/source/happyml-logo.png
    :width: 200px
    :align: center
    :alt: HappyML logo


HappyML (Machine Learning Python Library)
=========================================

|Build Status| |Coverage Status| |Code Health| |Documentation Status|
|PyPI version| |License|

.. |Build Status| image:: https://travis-ci.org/guiferviz/happyml-py.svg?branch=dev
   :target: https://travis-ci.org/guiferviz/happyml-py
.. |Coverage Status| image:: https://coveralls.io/repos/github/guiferviz/happyml-py/badge.svg?branch=dev
   :target: https://coveralls.io/github/guiferviz/happyml-py?branch=dev
.. |Code Health| image:: https://landscape.io/github/guiferviz/happyml-py/dev/landscape.svg?style=flat
   :target: https://landscape.io/github/guiferviz/happyml-py/dev
.. |Documentation Status| image:: https://readthedocs.org/projects/happyml/badge/?version=dev
   :target: http://happyml.readthedocs.io/en/dev/?badge=dev
.. |PyPI version| image:: https://badge.fury.io/py/happyml.svg
   :target: https://badge.fury.io/py/happyml
.. |License| image:: https://img.shields.io/badge/license-GPL-blue.svg
   :target: ./LICENSE

Machine Learning Python library for academic purposes. *HappyML* is a
little project supposed to be used by beginners in the Machine Learning
field. It has simple implementations of the more common algorithms.
*HappyML* only depends on *numpy* and *matplotlib*. The high level of
those libraries makes easy to write and read the code.


Installation
------------

You can install ``happyml`` easily using ``pip``::

    pip install happyml

If you prefer you can clone the repository and install the library via
``setup.py``::

    git clone https://github.com/guiferviz/happyml-py.git happyml
    cd happyml
    sudo python setup.py install


Getting started
---------------

Check your installation with:

.. code:: python

    import happyml
    happyml.greet()

If everything is OK you will see the output:

    Those about to learn we salute you :)


Documentation
-------------

Dev documentation: http://happyml.readthedocs.io/en/dev/


Contact
-------

Mail me (`guiferviz`_) or create an issue.

.. _guiferviz: mailto:guiferviz@gmail.com




**Remember to be HAPPY :smile: :blush: :relaxed:**

